@@ -25,6 +25,40 @@ def modules(target, arg):
             or arg in first.lower()
         ): print(f'{name:>{width}} {first}')
 
+def manage(target, line):
+    cmd, *arg = line.split()
+    manager, command = cmd.split('.')
+    m = getattr(target, manager)
+    c = getattr(m, command)
+    ret = c(*arg)
+    if ret:
+        for vals in ret:
+            print('\t'.join(vals))
+
+def manager(target, arg):
+    manager = target.managers.items.get(arg)
+    if manager:
+        title = f'manager {arg}'
+        print(title)
+        print('-'*len(title))
+        print(manager.help())
+    else:
+        print(f' ! unkown manager ! {arg}')
+
+def managers(target, arg):
+    managers = target.managers.items
+    print('managers')
+    print('-------')
+    width = len(max(managers.keys(), key=len))+4
+    for name, mod in sorted(managers.items()):
+        hlp = mod.help()
+        first = hlp.split('\n')[0]
+        if (
+            not arg
+            or arg in name
+            or arg in first.lower()
+        ): print(f'{name:>{width}} {first}')
+
 def deploy(target, arg):
     target.deploy(arg)
 
@@ -62,9 +96,6 @@ def remove(target, arg):
 def cleanup(target, arg):
     target.Package.cleanup()
 
-def flatpak(target, arg):
-    target.flatpak.install(arg)
-
 def status(target, arg):
     target.Service.status(arg)
 
