@@ -6,6 +6,11 @@ helps = dict(
     modules = '''list modules
         arg = search pattern
     ''',
+    manager = '''show manager's help
+    ''',
+    managers = '''list managers
+        arg = search pattern
+    ''',
     deploy = '''deploy module
     ''',
     remote = '''deploy module remotly
